@@ -9,7 +9,7 @@ from .account import Account
 from .user import User
 from .token import Token
 
-__version__ = "1.0.27"
+__version__ = "1.1.0"
 
 
 class FreedomClient(object):
@@ -82,16 +82,22 @@ class FreedomClient(object):
             return []
         return [User(user_data["user"], user_data, api=self.api) for user_data in result]
 
-    def get_tokens(self, params=None, api_call_kwargs={}):
+    def get_token(self, token_id, params=None, api_call_kwargs={}):
         """:obj:`list` of :obj:`dict`: Fetch a list of tokens.
 
         Args:
+            token_id (str): Token ID.
             params (dict): Optional query parameters.
             api_call_kwargs (dict): Optional keyword arguments for api call.
         """
 
-        result = self.api.call("GET", "/accounts", params=params, **api_call_kwargs)
-        return result
+        data = self.api.call(
+            "GET",
+            "/tokens/{}".format(token_id),
+            params=params,
+            **api_call_kwargs
+        )
+        return Token(data['token'], data, api=self.api, **api_call_kwargs)
 
     def create_token(
             self,
@@ -136,7 +142,7 @@ class FreedomClient(object):
         if raw:
             return result
         else:
-            return Token(result['token'], api=self.api)
+            return Token(result['token'], result, api=self.api)
 
     def delete_token(self, token_id, params=None, api_call_kwargs={}):
         """Deletes a specified token.
