@@ -6,8 +6,10 @@ from .alert import get_alert, get_alerts
 from .device import Device
 from .entity import Entity
 from .zone import Zone
+from .token import Token
 from .api_handler import NotFoundError
 
+
 class Account(Entity):
     """An account within the Freedom Robotics API. Normally fetched from a :obj:`FreedomClient`
     and not intended to be manually instantiated by the user of the API.
@@ -16,8 +18,10 @@ class Account(Entity):
         _id (str): Account ID.
         _data (`dict`): Account data.
     """
+    pk = 'account'
 
-    def _make_url(self):
+    @property
+    def url_base(self):
         return "/accounts/{}".format(self._id)
 
     @property
@@ -412,3 +416,40 @@ class Account(Entity):
             **api_call_kwargs
         )
 
+    def get_token(self, token_id, params=None, api_call_kwargs={}):
+        """:obj:`list` of :obj:`dict`: Fetch a list of tokens.
+
+        Args:
+            token_id (str): Token ID.
+            params (dict): Optional query parameters.
+            api_call_kwargs (dict): Optional keyword arguments for api call.
+        """
+
+        data = self.api.call(
+            "GET",
+            "/accounts/{}/tokens/{}".format(self._id, token_id),
+            params=params,
+            **api_call_kwargs
+        )
+        return Token(data['token'], data, account_id=self._id, api=self.api, **api_call_kwargs)
+
+    def get_tokens(self, params=None, api_call_kwargs={}):
+        """:obj:`list` of :obj:`dict`: Fetch a list of tokens.
+
+        Args:
+            params (dict): Optional query parameters.
+            api_call_kwargs (dict): Optional keyword arguments for api call.
+        """
+
+        result = self.api.call(
+            "GET",
+            "/accounts/{}/tokens".format(self._id),
+            params=params,
+            **api_call_kwargs
+        )
+        if not result:
+            return []
+        return [
+            Token(token_data['token'], token_data, account_id=self._id, api=self.api)
+            for token_data in result
+        ]
